# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/resources/feed_item.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v0.proto.common import custom_parameter_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_common_dot_custom__parameter__pb2
from google.ads.google_ads.v0.proto.common import feed_common_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_common_dot_feed__common__pb2
from google.ads.google_ads.v0.proto.enums import feed_item_status_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_enums_dot_feed__item__status__pb2
from google.ads.google_ads.v0.proto.enums import geo_targeting_restriction_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_enums_dot_geo__targeting__restriction__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/resources/feed_item.proto',
  package='google.ads.googleads.v0.resources',
  syntax='proto3',
  serialized_pb=_b('\n7google/ads/googleads_v0/proto/resources/feed_item.proto\x12!google.ads.googleads.v0.resources\x1a;google/ads/googleads_v0/proto/common/custom_parameter.proto\x1a\x36google/ads/googleads_v0/proto/common/feed_common.proto\x1a:google/ads/googleads_v0/proto/enums/feed_item_status.proto\x1a\x43google/ads/googleads_v0/proto/enums/geo_targeting_restriction.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\xd0\x04\n\x08\x46\x65\x65\x64Item\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12*\n\x04\x66\x65\x65\x64\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\'\n\x02id\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x35\n\x0fstart_date_time\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x33\n\rend_date_time\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12S\n\x10\x61ttribute_values\x18\x06 \x03(\x0b\x32\x39.google.ads.googleads.v0.resources.FeedItemAttributeValue\x12u\n\x19geo_targeting_restriction\x18\x07 \x01(\x0e\x32R.google.ads.googleads.v0.enums.GeoTargetingRestrictionEnum.GeoTargetingRestriction\x12N\n\x15url_custom_parameters\x18\x08 \x03(\x0b\x32/.google.ads.googleads.v0.common.CustomParameter\x12P\n\x06status\x18\t \x01(\x0e\x32@.google.ads.googleads.v0.enums.FeedItemStatusEnum.FeedItemStatus\"\xae\x04\n\x16\x46\x65\x65\x64ItemAttributeValue\x12\x36\n\x11\x66\x65\x65\x64_attribute_id\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x32\n\rinteger_value\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x31\n\rboolean_value\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x32\n\x0cstring_value\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x32\n\x0c\x64ouble_value\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12:\n\x0bprice_value\x18\x06 \x01(\x0b\x32%.google.ads.googleads.v0.common.Price\x12\x33\n\x0einteger_values\x18\x07 \x03(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x32\n\x0e\x62oolean_values\x18\x08 \x03(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x33\n\rstring_values\x18\t \x03(\x0b\x32\x1c.google.protobuf.StringValue\x12\x33\n\rdouble_values\x18\n \x03(\x0b\x32\x1c.google.protobuf.DoubleValueB\xd2\x01\n%com.google.ads.googleads.v0.resourcesB\rFeedItemProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v0/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V0.Resources\xca\x02!Google\\Ads\\GoogleAds\\V0\\Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v0_dot_proto_dot_common_dot_custom__parameter__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v0_dot_proto_dot_common_dot_feed__common__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v0_dot_proto_dot_enums_dot_feed__item__status__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v0_dot_proto_dot_enums_dot_geo__targeting__restriction__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,])




_FEEDITEM = _descriptor.Descriptor(
  name='FeedItem',
  full_name='google.ads.googleads.v0.resources.FeedItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.resources.FeedItem.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='feed', full_name='google.ads.googleads.v0.resources.FeedItem.feed', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='google.ads.googleads.v0.resources.FeedItem.id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_date_time', full_name='google.ads.googleads.v0.resources.FeedItem.start_date_time', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_date_time', full_name='google.ads.googleads.v0.resources.FeedItem.end_date_time', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attribute_values', full_name='google.ads.googleads.v0.resources.FeedItem.attribute_values', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='geo_targeting_restriction', full_name='google.ads.googleads.v0.resources.FeedItem.geo_targeting_restriction', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='url_custom_parameters', full_name='google.ads.googleads.v0.resources.FeedItem.url_custom_parameters', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='google.ads.googleads.v0.resources.FeedItem.status', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=373,
  serialized_end=965,
)


_FEEDITEMATTRIBUTEVALUE = _descriptor.Descriptor(
  name='FeedItemAttributeValue',
  full_name='google.ads.googleads.v0.resources.FeedItemAttributeValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='feed_attribute_id', full_name='google.ads.googleads.v0.resources.FeedItemAttributeValue.feed_attribute_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='integer_value', full_name='google.ads.googleads.v0.resources.FeedItemAttributeValue.integer_value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='boolean_value', full_name='google.ads.googleads.v0.resources.FeedItemAttributeValue.boolean_value', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='string_value', full_name='google.ads.googleads.v0.resources.FeedItemAttributeValue.string_value', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='double_value', full_name='google.ads.googleads.v0.resources.FeedItemAttributeValue.double_value', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='price_value', full_name='google.ads.googleads.v0.resources.FeedItemAttributeValue.price_value', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='integer_values', full_name='google.ads.googleads.v0.resources.FeedItemAttributeValue.integer_values', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='boolean_values', full_name='google.ads.googleads.v0.resources.FeedItemAttributeValue.boolean_values', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='string_values', full_name='google.ads.googleads.v0.resources.FeedItemAttributeValue.string_values', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='double_values', full_name='google.ads.googleads.v0.resources.FeedItemAttributeValue.double_values', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=968,
  serialized_end=1526,
)

_FEEDITEM.fields_by_name['feed'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_FEEDITEM.fields_by_name['id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_FEEDITEM.fields_by_name['start_date_time'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_FEEDITEM.fields_by_name['end_date_time'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_FEEDITEM.fields_by_name['attribute_values'].message_type = _FEEDITEMATTRIBUTEVALUE
_FEEDITEM.fields_by_name['geo_targeting_restriction'].enum_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_enums_dot_geo__targeting__restriction__pb2._GEOTARGETINGRESTRICTIONENUM_GEOTARGETINGRESTRICTION
_FEEDITEM.fields_by_name['url_custom_parameters'].message_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_common_dot_custom__parameter__pb2._CUSTOMPARAMETER
_FEEDITEM.fields_by_name['status'].enum_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_enums_dot_feed__item__status__pb2._FEEDITEMSTATUSENUM_FEEDITEMSTATUS
_FEEDITEMATTRIBUTEVALUE.fields_by_name['feed_attribute_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_FEEDITEMATTRIBUTEVALUE.fields_by_name['integer_value'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_FEEDITEMATTRIBUTEVALUE.fields_by_name['boolean_value'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_FEEDITEMATTRIBUTEVALUE.fields_by_name['string_value'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_FEEDITEMATTRIBUTEVALUE.fields_by_name['double_value'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_FEEDITEMATTRIBUTEVALUE.fields_by_name['price_value'].message_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_common_dot_feed__common__pb2._PRICE
_FEEDITEMATTRIBUTEVALUE.fields_by_name['integer_values'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_FEEDITEMATTRIBUTEVALUE.fields_by_name['boolean_values'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_FEEDITEMATTRIBUTEVALUE.fields_by_name['string_values'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_FEEDITEMATTRIBUTEVALUE.fields_by_name['double_values'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
DESCRIPTOR.message_types_by_name['FeedItem'] = _FEEDITEM
DESCRIPTOR.message_types_by_name['FeedItemAttributeValue'] = _FEEDITEMATTRIBUTEVALUE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FeedItem = _reflection.GeneratedProtocolMessageType('FeedItem', (_message.Message,), dict(
  DESCRIPTOR = _FEEDITEM,
  __module__ = 'google.ads.google_ads.v0.proto.resources.feed_item_pb2'
  ,
  __doc__ = """A feed item.
  
  
  Attributes:
      resource_name:
          The resource name of the feed item. Feed item resource names
          have the form:
          ``customers/{customer_id}/feedItems/{feed_id}_{feed_item_id}``
      feed:
          The feed to which this feed item belongs.
      id:
          The ID of this feed item.
      start_date_time:
          Start time in which this feed item is effective and can begin
          serving. The format is "YYYY-MM-DD HH:MM:SS". Examples:
          "2018-03-05 09:15:00" or "2018-02-01 14:34:30"
      end_date_time:
          End time in which this feed item is no longer effective and
          will stop The format is "YYYY-MM-DD HH:MM:SS". Examples:
          "2018-03-05 09:15:00" or "2018-02-01 14:34:30"
      attribute_values:
          The feed item's attribute values.
      geo_targeting_restriction:
          Geo targeting restriction specifies the type of location that
          can be used for targeting.
      url_custom_parameters:
          The list of mappings used to substitute custom parameter tags
          in a ``tracking_url_template``, ``final_urls``, or
          ``mobile_final_urls``.
      status:
          Status of the feed item. This field is read-only.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.resources.FeedItem)
  ))
_sym_db.RegisterMessage(FeedItem)

FeedItemAttributeValue = _reflection.GeneratedProtocolMessageType('FeedItemAttributeValue', (_message.Message,), dict(
  DESCRIPTOR = _FEEDITEMATTRIBUTEVALUE,
  __module__ = 'google.ads.google_ads.v0.proto.resources.feed_item_pb2'
  ,
  __doc__ = """A feed item attribute value.
  
  
  Attributes:
      feed_attribute_id:
          Id of the feed attribute for which the value is associated
          with.
      integer_value:
          Int64 value. Should be set if feed\_attribute\_id refers to a
          feed attribute of type INT64.
      boolean_value:
          Bool value. Should be set if feed\_attribute\_id refers to a
          feed attribute of type BOOLEAN.
      string_value:
          String value. Should be set if feed\_attribute\_id refers to a
          feed attribute of type STRING, URL or DATE\_TIME. For STRING
          the maximum length is 1500 characters. For URL the maximum
          length is 2076 characters. For DATE\_TIME the format of the
          string must be the same as start and end time for the feed
          item.
      double_value:
          Double value. Should be set if feed\_attribute\_id refers to a
          feed attribute of type DOUBLE.
      price_value:
          Price value. Should be set if feed\_attribute\_id refers to a
          feed attribute of type PRICE.
      integer_values:
          Repeated int64 value. Should be set if feed\_attribute\_id
          refers to a feed attribute of type INT64\_LIST.
      boolean_values:
          Repeated bool value. Should be set if feed\_attribute\_id
          refers to a feed attribute of type BOOLEAN\_LIST.
      string_values:
          Repeated string value. Should be set if feed\_attribute\_id
          refers to a feed attribute of type STRING\_LIST, URL\_LIST or
          DATE\_TIME\_LIST. For STRING\_LIST and URL\_LIST the total
          size of the list in bytes may not exceed 3000. For
          DATE\_TIME\_LIST the number of elements may not exceed 200.
          For STRING\_LIST the maximum length of each string element is
          1500 characters. For URL\_LIST the maximum length is 2076
          characters. For DATE\_TIME the format of the string must be
          the same as start and end time for the feed item.
      double_values:
          Repeated double value. Should be set if feed\_attribute\_id
          refers to a feed attribute of type DOUBLE\_LIST.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.resources.FeedItemAttributeValue)
  ))
_sym_db.RegisterMessage(FeedItemAttributeValue)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n%com.google.ads.googleads.v0.resourcesB\rFeedItemProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v0/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V0.Resources\312\002!Google\\Ads\\GoogleAds\\V0\\Resources'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/enums/placeholder_type.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/enums/placeholder_type.proto',
  package='google.ads.googleads.v0.enums',
  syntax='proto3',
  serialized_pb=_b('\n:google/ads/googleads_v0/proto/enums/placeholder_type.proto\x12\x1dgoogle.ads.googleads.v0.enums\"\x90\x03\n\x13PlaceholderTypeEnum\"\xf8\x02\n\x0fPlaceholderType\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x0c\n\x08SITELINK\x10\x02\x12\x08\n\x04\x43\x41LL\x10\x03\x12\x07\n\x03\x41PP\x10\x04\x12\x0c\n\x08LOCATION\x10\x05\x12\x16\n\x12\x41\x46\x46ILIATE_LOCATION\x10\x06\x12\x0b\n\x07\x43\x41LLOUT\x10\x07\x12\x16\n\x12STRUCTURED_SNIPPET\x10\x08\x12\x0b\n\x07MESSAGE\x10\t\x12\t\n\x05PRICE\x10\n\x12\r\n\tPROMOTION\x10\x0b\x12\x11\n\rAD_CUSTOMIZER\x10\x0c\x12\x15\n\x11\x44YNAMIC_EDUCATION\x10\r\x12\x12\n\x0e\x44YNAMIC_FLIGHT\x10\x0e\x12\x12\n\x0e\x44YNAMIC_CUSTOM\x10\x0f\x12\x11\n\rDYNAMIC_HOTEL\x10\x10\x12\x17\n\x13\x44YNAMIC_REAL_ESTATE\x10\x11\x12\x12\n\x0e\x44YNAMIC_TRAVEL\x10\x12\x12\x11\n\rDYNAMIC_LOCAL\x10\x13\x12\x0f\n\x0b\x44YNAMIC_JOB\x10\x14\x42\xc5\x01\n!com.google.ads.googleads.v0.enumsB\x14PlaceholderTypeProtoP\x01ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v0/enums;enums\xa2\x02\x03GAA\xaa\x02\x1dGoogle.Ads.GoogleAds.V0.Enums\xca\x02\x1dGoogle\\Ads\\GoogleAds\\V0\\Enumsb\x06proto3')
)



_PLACEHOLDERTYPEENUM_PLACEHOLDERTYPE = _descriptor.EnumDescriptor(
  name='PlaceholderType',
  full_name='google.ads.googleads.v0.enums.PlaceholderTypeEnum.PlaceholderType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SITELINK', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CALL', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='APP', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOCATION', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AFFILIATE_LOCATION', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CALLOUT', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STRUCTURED_SNIPPET', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MESSAGE', index=9, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRICE', index=10, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROMOTION', index=11, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AD_CUSTOMIZER', index=12, number=12,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DYNAMIC_EDUCATION', index=13, number=13,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DYNAMIC_FLIGHT', index=14, number=14,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DYNAMIC_CUSTOM', index=15, number=15,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DYNAMIC_HOTEL', index=16, number=16,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DYNAMIC_REAL_ESTATE', index=17, number=17,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DYNAMIC_TRAVEL', index=18, number=18,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DYNAMIC_LOCAL', index=19, number=19,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DYNAMIC_JOB', index=20, number=20,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=118,
  serialized_end=494,
)
_sym_db.RegisterEnumDescriptor(_PLACEHOLDERTYPEENUM_PLACEHOLDERTYPE)


_PLACEHOLDERTYPEENUM = _descriptor.Descriptor(
  name='PlaceholderTypeEnum',
  full_name='google.ads.googleads.v0.enums.PlaceholderTypeEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PLACEHOLDERTYPEENUM_PLACEHOLDERTYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=94,
  serialized_end=494,
)

_PLACEHOLDERTYPEENUM_PLACEHOLDERTYPE.containing_type = _PLACEHOLDERTYPEENUM
DESCRIPTOR.message_types_by_name['PlaceholderTypeEnum'] = _PLACEHOLDERTYPEENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PlaceholderTypeEnum = _reflection.GeneratedProtocolMessageType('PlaceholderTypeEnum', (_message.Message,), dict(
  DESCRIPTOR = _PLACEHOLDERTYPEENUM,
  __module__ = 'google.ads.google_ads.v0.proto.enums.placeholder_type_pb2'
  ,
  __doc__ = """Container for enum describing possible placeholder types for a feed
  mapping.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.enums.PlaceholderTypeEnum)
  ))
_sym_db.RegisterMessage(PlaceholderTypeEnum)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n!com.google.ads.googleads.v0.enumsB\024PlaceholderTypeProtoP\001ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v0/enums;enums\242\002\003GAA\252\002\035Google.Ads.GoogleAds.V0.Enums\312\002\035Google\\Ads\\GoogleAds\\V0\\Enums'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/services/keyword_plan_keyword_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v0.proto.resources import keyword_plan_keyword_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_keyword__plan__keyword__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/services/keyword_plan_keyword_service.proto',
  package='google.ads.googleads.v0.services',
  syntax='proto3',
  serialized_pb=_b('\nIgoogle/ads/googleads_v0/proto/services/keyword_plan_keyword_service.proto\x12 google.ads.googleads.v0.services\x1a\x42google/ads/googleads_v0/proto/resources/keyword_plan_keyword.proto\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\"5\n\x1cGetKeywordPlanKeywordRequest\x12\x15\n\rresource_name\x18\x01 \x01(\t\"\x8a\x01\n MutateKeywordPlanKeywordsRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12Q\n\noperations\x18\x02 \x03(\x0b\x32=.google.ads.googleads.v0.services.KeywordPlanKeywordOperation\"\xff\x01\n\x1bKeywordPlanKeywordOperation\x12/\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12G\n\x06\x63reate\x18\x01 \x01(\x0b\x32\x35.google.ads.googleads.v0.resources.KeywordPlanKeywordH\x00\x12G\n\x06update\x18\x02 \x01(\x0b\x32\x35.google.ads.googleads.v0.resources.KeywordPlanKeywordH\x00\x12\x10\n\x06remove\x18\x03 \x01(\tH\x00\x42\x0b\n\toperation\"v\n!MutateKeywordPlanKeywordsResponse\x12Q\n\x07results\x18\x02 \x03(\x0b\x32@.google.ads.googleads.v0.services.MutateKeywordPlanKeywordResult\"7\n\x1eMutateKeywordPlanKeywordResult\x12\x15\n\rresource_name\x18\x01 \x01(\t2\xd7\x03\n\x19KeywordPlanKeywordService\x12\xcd\x01\n\x15GetKeywordPlanKeyword\x12>.google.ads.googleads.v0.services.GetKeywordPlanKeywordRequest\x1a\x35.google.ads.googleads.v0.resources.KeywordPlanKeyword\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/v0/{resource_name=customers/*/keywordPlanKeywords/*}\x12\xe9\x01\n\x19MutateKeywordPlanKeywords\x12\x42.google.ads.googleads.v0.services.MutateKeywordPlanKeywordsRequest\x1a\x43.google.ads.googleads.v0.services.MutateKeywordPlanKeywordsResponse\"C\x82\xd3\xe4\x93\x02=\"8/v0/customers/{customer_id=*}/keywordPlanKeywords:mutate:\x01*B\xde\x01\n$com.google.ads.googleads.v0.servicesB\x1eKeywordPlanKeywordServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V0.Services\xca\x02 Google\\Ads\\GoogleAds\\V0\\Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_keyword__plan__keyword__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,])




_GETKEYWORDPLANKEYWORDREQUEST = _descriptor.Descriptor(
  name='GetKeywordPlanKeywordRequest',
  full_name='google.ads.googleads.v0.services.GetKeywordPlanKeywordRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.services.GetKeywordPlanKeywordRequest.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=243,
  serialized_end=296,
)


_MUTATEKEYWORDPLANKEYWORDSREQUEST = _descriptor.Descriptor(
  name='MutateKeywordPlanKeywordsRequest',
  full_name='google.ads.googleads.v0.services.MutateKeywordPlanKeywordsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v0.services.MutateKeywordPlanKeywordsRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operations', full_name='google.ads.googleads.v0.services.MutateKeywordPlanKeywordsRequest.operations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=299,
  serialized_end=437,
)


_KEYWORDPLANKEYWORDOPERATION = _descriptor.Descriptor(
  name='KeywordPlanKeywordOperation',
  full_name='google.ads.googleads.v0.services.KeywordPlanKeywordOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='google.ads.googleads.v0.services.KeywordPlanKeywordOperation.update_mask', index=0,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='create', full_name='google.ads.googleads.v0.services.KeywordPlanKeywordOperation.create', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update', full_name='google.ads.googleads.v0.services.KeywordPlanKeywordOperation.update', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove', full_name='google.ads.googleads.v0.services.KeywordPlanKeywordOperation.remove', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='operation', full_name='google.ads.googleads.v0.services.KeywordPlanKeywordOperation.operation',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=440,
  serialized_end=695,
)


_MUTATEKEYWORDPLANKEYWORDSRESPONSE = _descriptor.Descriptor(
  name='MutateKeywordPlanKeywordsResponse',
  full_name='google.ads.googleads.v0.services.MutateKeywordPlanKeywordsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='google.ads.googleads.v0.services.MutateKeywordPlanKeywordsResponse.results', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=697,
  serialized_end=815,
)


_MUTATEKEYWORDPLANKEYWORDRESULT = _descriptor.Descriptor(
  name='MutateKeywordPlanKeywordResult',
  full_name='google.ads.googleads.v0.services.MutateKeywordPlanKeywordResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.services.MutateKeywordPlanKeywordResult.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=817,
  serialized_end=872,
)

_MUTATEKEYWORDPLANKEYWORDSREQUEST.fields_by_name['operations'].message_type = _KEYWORDPLANKEYWORDOPERATION
_KEYWORDPLANKEYWORDOPERATION.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_KEYWORDPLANKEYWORDOPERATION.fields_by_name['create'].message_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_keyword__plan__keyword__pb2._KEYWORDPLANKEYWORD
_KEYWORDPLANKEYWORDOPERATION.fields_by_name['update'].message_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_keyword__plan__keyword__pb2._KEYWORDPLANKEYWORD
_KEYWORDPLANKEYWORDOPERATION.oneofs_by_name['operation'].fields.append(
  _KEYWORDPLANKEYWORDOPERATION.fields_by_name['create'])
_KEYWORDPLANKEYWORDOPERATION.fields_by_name['create'].containing_oneof = _KEYWORDPLANKEYWORDOPERATION.oneofs_by_name['operation']
_KEYWORDPLANKEYWORDOPERATION.oneofs_by_name['operation'].fields.append(
  _KEYWORDPLANKEYWORDOPERATION.fields_by_name['update'])
_KEYWORDPLANKEYWORDOPERATION.fields_by_name['update'].containing_oneof = _KEYWORDPLANKEYWORDOPERATION.oneofs_by_name['operation']
_KEYWORDPLANKEYWORDOPERATION.oneofs_by_name['operation'].fields.append(
  _KEYWORDPLANKEYWORDOPERATION.fields_by_name['remove'])
_KEYWORDPLANKEYWORDOPERATION.fields_by_name['remove'].containing_oneof = _KEYWORDPLANKEYWORDOPERATION.oneofs_by_name['operation']
_MUTATEKEYWORDPLANKEYWORDSRESPONSE.fields_by_name['results'].message_type = _MUTATEKEYWORDPLANKEYWORDRESULT
DESCRIPTOR.message_types_by_name['GetKeywordPlanKeywordRequest'] = _GETKEYWORDPLANKEYWORDREQUEST
DESCRIPTOR.message_types_by_name['MutateKeywordPlanKeywordsRequest'] = _MUTATEKEYWORDPLANKEYWORDSREQUEST
DESCRIPTOR.message_types_by_name['KeywordPlanKeywordOperation'] = _KEYWORDPLANKEYWORDOPERATION
DESCRIPTOR.message_types_by_name['MutateKeywordPlanKeywordsResponse'] = _MUTATEKEYWORDPLANKEYWORDSRESPONSE
DESCRIPTOR.message_types_by_name['MutateKeywordPlanKeywordResult'] = _MUTATEKEYWORDPLANKEYWORDRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetKeywordPlanKeywordRequest = _reflection.GeneratedProtocolMessageType('GetKeywordPlanKeywordRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETKEYWORDPLANKEYWORDREQUEST,
  __module__ = 'google.ads.google_ads.v0.proto.services.keyword_plan_keyword_service_pb2'
  ,
  __doc__ = """Request message for
  [KeywordPlanKeywordService.GetKeywordPlanKeyword][google.ads.googleads.v0.services.KeywordPlanKeywordService.GetKeywordPlanKeyword].
  
  
  Attributes:
      resource_name:
          The resource name of the ad group keyword to fetch.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.GetKeywordPlanKeywordRequest)
  ))
_sym_db.RegisterMessage(GetKeywordPlanKeywordRequest)

MutateKeywordPlanKeywordsRequest = _reflection.GeneratedProtocolMessageType('MutateKeywordPlanKeywordsRequest', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEKEYWORDPLANKEYWORDSREQUEST,
  __module__ = 'google.ads.google_ads.v0.proto.services.keyword_plan_keyword_service_pb2'
  ,
  __doc__ = """Request message for
  [KeywordPlanKeywordService.MutateKeywordPlanKeywords][google.ads.googleads.v0.services.KeywordPlanKeywordService.MutateKeywordPlanKeywords].
  
  
  Attributes:
      customer_id:
          The ID of the customer whose Keyword Plan keywords are being
          modified.
      operations:
          The list of operations to perform on individual Keyword Plan
          keywords.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateKeywordPlanKeywordsRequest)
  ))
_sym_db.RegisterMessage(MutateKeywordPlanKeywordsRequest)

KeywordPlanKeywordOperation = _reflection.GeneratedProtocolMessageType('KeywordPlanKeywordOperation', (_message.Message,), dict(
  DESCRIPTOR = _KEYWORDPLANKEYWORDOPERATION,
  __module__ = 'google.ads.google_ads.v0.proto.services.keyword_plan_keyword_service_pb2'
  ,
  __doc__ = """A single operation (create, update, remove) on a Keyword Plan keyword.
  
  
  Attributes:
      update_mask:
          The FieldMask that determines which resource fields are
          modified in an update.
      operation:
          The mutate operation.
      create:
          Create operation: No resource name is expected for the new
          Keyword Plan ad group keyword.
      update:
          Update operation: The Keyword Plan keyword is expected to have
          a valid resource name.
      remove:
          Remove operation: A resource name for the removed Keyword Plan
          keyword is expected, in this format:  ``customers/{customer_id
          }/keywordPlanKeywords/{kp_ad_group_keyword_id}``
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.KeywordPlanKeywordOperation)
  ))
_sym_db.RegisterMessage(KeywordPlanKeywordOperation)

MutateKeywordPlanKeywordsResponse = _reflection.GeneratedProtocolMessageType('MutateKeywordPlanKeywordsResponse', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEKEYWORDPLANKEYWORDSRESPONSE,
  __module__ = 'google.ads.google_ads.v0.proto.services.keyword_plan_keyword_service_pb2'
  ,
  __doc__ = """Response message for a Keyword Plan keyword mutate.
  
  
  Attributes:
      results:
          All results for the mutate.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateKeywordPlanKeywordsResponse)
  ))
_sym_db.RegisterMessage(MutateKeywordPlanKeywordsResponse)

MutateKeywordPlanKeywordResult = _reflection.GeneratedProtocolMessageType('MutateKeywordPlanKeywordResult', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEKEYWORDPLANKEYWORDRESULT,
  __module__ = 'google.ads.google_ads.v0.proto.services.keyword_plan_keyword_service_pb2'
  ,
  __doc__ = """The result for the Keyword Plan keyword mutate.
  
  
  Attributes:
      resource_name:
          Returned for successful operations.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateKeywordPlanKeywordResult)
  ))
_sym_db.RegisterMessage(MutateKeywordPlanKeywordResult)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n$com.google.ads.googleads.v0.servicesB\036KeywordPlanKeywordServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V0.Services\312\002 Google\\Ads\\GoogleAds\\V0\\Services'))

_KEYWORDPLANKEYWORDSERVICE = _descriptor.ServiceDescriptor(
  name='KeywordPlanKeywordService',
  full_name='google.ads.googleads.v0.services.KeywordPlanKeywordService',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=875,
  serialized_end=1346,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetKeywordPlanKeyword',
    full_name='google.ads.googleads.v0.services.KeywordPlanKeywordService.GetKeywordPlanKeyword',
    index=0,
    containing_service=None,
    input_type=_GETKEYWORDPLANKEYWORDREQUEST,
    output_type=google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_keyword__plan__keyword__pb2._KEYWORDPLANKEYWORD,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\0027\0225/v0/{resource_name=customers/*/keywordPlanKeywords/*}')),
  ),
  _descriptor.MethodDescriptor(
    name='MutateKeywordPlanKeywords',
    full_name='google.ads.googleads.v0.services.KeywordPlanKeywordService.MutateKeywordPlanKeywords',
    index=1,
    containing_service=None,
    input_type=_MUTATEKEYWORDPLANKEYWORDSREQUEST,
    output_type=_MUTATEKEYWORDPLANKEYWORDSRESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002=\"8/v0/customers/{customer_id=*}/keywordPlanKeywords:mutate:\001*')),
  ),
])
_sym_db.RegisterServiceDescriptor(_KEYWORDPLANKEYWORDSERVICE)

DESCRIPTOR.services_by_name['KeywordPlanKeywordService'] = _KEYWORDPLANKEYWORDSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/services/topic_constant_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v0.proto.resources import topic_constant_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_topic__constant__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/services/topic_constant_service.proto',
  package='google.ads.googleads.v0.services',
  syntax='proto3',
  serialized_pb=_b('\nCgoogle/ads/googleads_v0/proto/services/topic_constant_service.proto\x12 google.ads.googleads.v0.services\x1a<google/ads/googleads_v0/proto/resources/topic_constant.proto\x1a\x1cgoogle/api/annotations.proto\"0\n\x17GetTopicConstantRequest\x12\x15\n\rresource_name\x18\x01 \x01(\t2\xc6\x01\n\x14TopicConstantService\x12\xad\x01\n\x10GetTopicConstant\x12\x39.google.ads.googleads.v0.services.GetTopicConstantRequest\x1a\x30.google.ads.googleads.v0.resources.TopicConstant\",\x82\xd3\xe4\x93\x02&\x12$/v0/{resource_name=topicConstants/*}B\xd9\x01\n$com.google.ads.googleads.v0.servicesB\x19TopicConstantServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V0.Services\xca\x02 Google\\Ads\\GoogleAds\\V0\\Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_topic__constant__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_GETTOPICCONSTANTREQUEST = _descriptor.Descriptor(
  name='GetTopicConstantRequest',
  full_name='google.ads.googleads.v0.services.GetTopicConstantRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.services.GetTopicConstantRequest.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=197,
  serialized_end=245,
)

DESCRIPTOR.message_types_by_name['GetTopicConstantRequest'] = _GETTOPICCONSTANTREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetTopicConstantRequest = _reflection.GeneratedProtocolMessageType('GetTopicConstantRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETTOPICCONSTANTREQUEST,
  __module__ = 'google.ads.google_ads.v0.proto.services.topic_constant_service_pb2'
  ,
  __doc__ = """Request message for
  [TopicConstantService.GetTopicConstant][google.ads.googleads.v0.services.TopicConstantService.GetTopicConstant].
  
  
  Attributes:
      resource_name:
          Resource name of the Topic to fetch.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.GetTopicConstantRequest)
  ))
_sym_db.RegisterMessage(GetTopicConstantRequest)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n$com.google.ads.googleads.v0.servicesB\031TopicConstantServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V0.Services\312\002 Google\\Ads\\GoogleAds\\V0\\Services'))

_TOPICCONSTANTSERVICE = _descriptor.ServiceDescriptor(
  name='TopicConstantService',
  full_name='google.ads.googleads.v0.services.TopicConstantService',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=248,
  serialized_end=446,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetTopicConstant',
    full_name='google.ads.googleads.v0.services.TopicConstantService.GetTopicConstant',
    index=0,
    containing_service=None,
    input_type=_GETTOPICCONSTANTREQUEST,
    output_type=google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_topic__constant__pb2._TOPICCONSTANT,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002&\022$/v0/{resource_name=topicConstants/*}')),
  ),
])
_sym_db.RegisterServiceDescriptor(_TOPICCONSTANTSERVICE)

DESCRIPTOR.services_by_name['TopicConstantService'] = _TOPICCONSTANTSERVICE

# @@protoc_insertion_point(module_scope)
